//!
//! Cryptographic functions
//! for generating keys and
//! encrypting traffic
//!
pub mod gen_key;

#[cfg(test)]
mod tests {
    use super::gen_key::gen_key;
    #[test]
    fn it_works() {
        let result = 2 + 2;
        assert_eq!(result, 4);
    }

    #[test]
    fn test_key_gen() {
        gen_key();
    }
}
